define.clade: Define clade

View source: R/define.clade.R

define.cladeR Documentation

Define clade

Description

Function to define groups (clades) in a phylogenetic tree.

Usage

define.clade(tree, threshold, time, method = c("threshold", "time"))

Arguments

tree

Phylogenetic tree.

threshold

A threshold value to form the groups.

time

A cutting height (age) to form the groups.

method

Method to define the clades, "threshold" or "time".

Details

In the method threshold the total length of phylogenetic tree is used as cutting factor. If threshold is near to zero the cutting is near the root, if threshold near to one cutting is near the tips.

The phylogenetic tree must contain the node labels for the function work. Use the makeNodeLabel for defining node labels in a flexible way.

Value

clades

Tips and their clades.

height

The cutting height (age).

Author(s)

Vanderlei Julio Debastiani <vanderleidebastiani@yahoo.com.br>

See Also

makeNodeLabel

Examples


require(ape)	
tree<-makeNodeLabel(rcoal(10))
clades<-define.clade(tree, threshold = 0.8, method = "threshold")
clades
plot.phylo(tree, show.node.label = TRUE)
abline(v = clades$height)

PCPS documentation built on June 18, 2026, 1:07 a.m.

Related to define.clade in PCPS...