View source: R/mutate.names.matrix.p.null.R
| mutate.names.matrix.p.null | R Documentation |
Internal function to perform replacement names in object returned by matrix.p.null.
mutate.names.matrix.p.null(x, replacement, newname)
x |
An object returned by |
replacement |
A replacement name to matched in object returned by |
newname |
New name to be replaced in object returned by |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.